<?php
namespace Teknisa\FIS\Modules\Acessorias\Controllers;

use Teknisa\FIS\Modules\Acessorias\Services\Fis01600SintegraService;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Error;

class Fis01600SintegraController {

    protected $sintegraService;

    public function __construct(EntityManager $entityManager, Fis01600SintegraService $sintegraService) {
        $this->entityManager    = $entityManager;
        $this->sintegraService  = $sintegraService;
        set_time_limit(0);
    }

    /*
     * Função para realizar a exportação do SINTEGRA.
     */
    public function exportarSintegra(DTO\Request $request, DTO\Response $response) {
        try {
            
            $row = $request->getRow();
            
            $row["NMARQUIVO"] = str_replace(' ', '', $row["NMARQUIVO"]);
             
            
            // Chama a função de exportação.
            $fileName = $this->sintegraService->exportarSintegra($row);

            // Retorna o nome do arquivo exportado.
            $response->addDataset(new DataSet('columnsToReturn', array("fileName" => $fileName)));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function findAgendamento(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            
            $rows = $this->sintegraService->findAgendamento();
            
            $dataSet = new DataSet('agendobrigacess_fis01600', $rows);
            $response->setDataSets(array($dataSet));
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    } 
    
    public function saveAgendamento(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            $this->sintegraService->saveAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteAgendamento(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            // Chama a função de validação.
            $this->sintegraService->deleteAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function execAgendamentoSintegra(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getParameters();
            
            $this->sintegraService->execAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
 
}
